@@ -33,6 +33,7 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
 import github.PaginatedList
 
@@ -40,6 +41,7 @@ import github.GistComment
 import github.NamedUser
 import github.GistFile
 import github.GistHistoryState
+import six
 
 
 class Gist(github.GithubObject.CompletableGithubObject):
@@ -208,7 +210,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
         :param body: string
         :rtype: :class:`github.GistComment.GistComment`
         """
-        assert isinstance(body, str), body
+        assert isinstance(body, (str, six.text_type)), body
         post_parameters = {
             "body": body,
         }
@@ -247,13 +249,13 @@ class Gist(github.GithubObject.CompletableGithubObject):
         :param files: dict of string to :class:`github.InputFileContent.InputFileContent`
         :rtype: None
         """
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
-        assert files is github.GithubObject.NotSet or all(element is None or isinstance(element, github.InputFileContent) for element in files.values()), files
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
+        assert files is github.GithubObject.NotSet or all(element is None or isinstance(element, github.InputFileContent) for element in six.itervalues(files)), files
         post_parameters = dict()
         if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         if files is not github.GithubObject.NotSet:
-            post_parameters["files"] = {key: None if value is None else value._identity for key, value in files.items()}
+            post_parameters["files"] = {key: None if value is None else value._identity for key, value in six.iteritems(files)}
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
@@ -267,7 +269,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.GistComment.GistComment`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self.url + "/comments/" + str(id)
