@@ -30,7 +30,9 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
+import six
 
 
 class InputGitAuthor(object):
@@ -45,9 +47,9 @@ class InputGitAuthor(object):
         :param date: string
         """
 
-        assert isinstance(name, str), name
-        assert isinstance(email, str), email
-        assert date is github.GithubObject.NotSet or isinstance(date, str), date  # @todo Datetime?
+        assert isinstance(name, (str, six.text_type)), name
+        assert isinstance(email, (str, six.text_type)), email
+        assert date is github.GithubObject.NotSet or isinstance(date, (str, six.text_type)), date  # @todo Datetime?
 
         self.__name = name
         self.__email = email
