@@ -25,12 +25,12 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
 import github.PaginatedList
 
 import github.Gist
 import github.Repository
-import github.NamedUser
 import github.Plan
 import github.Organization
 import github.UserKey
