@@ -42,7 +42,8 @@
 #                                                                              #
 ################################################################################
 
-import urllib.request, urllib.parse, urllib.error
+from __future__ import absolute_import
+import six.moves.urllib.parse
 import datetime
 import github.GithubObject
 import github.PaginatedList
@@ -57,6 +58,7 @@ import github.IssuePullRequest
 import github.Reaction
 
 from . import Consts
+import six
 
 
 class Issue(github.GithubObject.CompletableGithubObject):
@@ -280,7 +282,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param assignee: :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.NamedUser.NamedUser, str)) for element in assignees), assignees
+        assert all(isinstance(element, (github.NamedUser.NamedUser, str, six.text_type)) for element in assignees), assignees
         post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
@@ -295,7 +297,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str)) for element in labels), labels
+        assert all(isinstance(element, (github.Label.Label, str, six.text_type)) for element in labels), labels
         post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
@@ -309,7 +311,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param body: string
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(body, str), body
+        assert isinstance(body, (str, six.text_type)), body
         post_parameters = {
             "body": body,
         }
@@ -342,20 +344,20 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param labels: list of string
         :rtype: None
         """
-        assert title is github.GithubObject.NotSet or isinstance(title, str), title
-        assert body is github.GithubObject.NotSet or isinstance(body, str), body
-        assert assignee is github.GithubObject.NotSet or assignee is None or isinstance(assignee, github.NamedUser.NamedUser) or isinstance(assignee, str), assignee
-        assert assignees is github.GithubObject.NotSet or all(isinstance(element, github.NamedUser.NamedUser) or isinstance(element, str) for element in assignees), assignees
-        assert state is github.GithubObject.NotSet or isinstance(state, str), state
+        assert title is github.GithubObject.NotSet or isinstance(title, (str, six.text_type)), title
+        assert body is github.GithubObject.NotSet or isinstance(body, (str, six.text_type)), body
+        assert assignee is github.GithubObject.NotSet or assignee is None or isinstance(assignee, github.NamedUser.NamedUser) or isinstance(assignee, (str, six.text_type)), assignee
+        assert assignees is github.GithubObject.NotSet or all(isinstance(element, github.NamedUser.NamedUser) or isinstance(element, (str, six.text_type)) for element in assignees), assignees
+        assert state is github.GithubObject.NotSet or isinstance(state, (str, six.text_type)), state
         assert milestone is github.GithubObject.NotSet or milestone is None or isinstance(milestone, github.Milestone.Milestone), milestone
-        assert labels is github.GithubObject.NotSet or all(isinstance(element, str) for element in labels), labels
+        assert labels is github.GithubObject.NotSet or all(isinstance(element, (str, six.text_type)) for element in labels), labels
         post_parameters = dict()
         if title is not github.GithubObject.NotSet:
             post_parameters["title"] = title
         if body is not github.GithubObject.NotSet:
             post_parameters["body"] = body
         if assignee is not github.GithubObject.NotSet:
-            if isinstance(assignee, str):
+            if isinstance(assignee, (str, six.text_type)):
                 post_parameters["assignee"] = assignee
             else:
                 post_parameters["assignee"] = assignee._identity if assignee else ''
@@ -380,7 +382,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param lock_reason: string
         :rtype: None
         """
-        assert isinstance(lock_reason, str), lock_reason
+        assert isinstance(lock_reason, (str, six.text_type)), lock_reason
         put_parameters = dict()
         put_parameters["lock_reason"] = lock_reason
         headers, data = self._requester.requestJsonAndCheck(
@@ -406,7 +408,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self._parentUrl(self.url) + "/comments/" + str(id)
@@ -461,7 +463,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param assignee: :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.NamedUser.NamedUser, str)) for element in assignees), assignees
+        assert all(isinstance(element, (github.NamedUser.NamedUser, str, six.text_type)) for element in assignees), assignees
         post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
@@ -476,11 +478,11 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert isinstance(label, (github.Label.Label, str)), label
+        assert isinstance(label, (github.Label.Label, str, six.text_type)), label
         if isinstance(label, github.Label.Label):
             label = label._identity
         else:
-            label = urllib.parse.quote(label)
+            label = six.moves.urllib.parse.quote(label)
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url + "/labels/" + label
@@ -492,7 +494,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param labels: list of :class:`github.Label.Label` or strings
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str)) for element in labels), labels
+        assert all(isinstance(element, (github.Label.Label, str, six.text_type)) for element in labels), labels
         post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
@@ -519,7 +521,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         :param reaction_type: string
         :rtype: :class:`github.Reaction.Reaction`
         """
-        assert isinstance(reaction_type, str), "reaction type should be a string"
+        assert isinstance(reaction_type, (str, six.text_type)), "reaction type should be a string"
         assert reaction_type in ["+1", "-1", "laugh", "confused", "heart", "hooray"], \
             "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
 
