@@ -28,6 +28,7 @@
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 # Copyright 2018 itsbruce <it.is.bruce@gmail.com>                              #
+# Copyright 2019 Tomas Tomecek <tomas@tomecek.net>                             #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -47,38 +48,33 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import datetime
 
-import urllib.request, urllib.parse, urllib.error
 import pickle
 import time
-import sys
 import requests
 import jwt
 import urllib3
 
 from .Requester import Requester
 from . import AuthenticatedUser
-from . import NamedUser
-from . import Organization
-from . import Gist
+import github.NamedUser
+import github.Gist
 import github.PaginatedList
 from . import Repository
 from . import Installation
-from . import Legacy
-from . import License
-from . import Topic
+import github.License
+import github.Topic
 import github.GithubObject
 from . import HookDescription
 from . import GitignoreTemplate
 from . import RateLimit
 from . import InstallationAuthorization
 from . import GithubException
-from . import Invitation
 
 from . import Consts
-
-atLeastPython3 = sys.hexversion >= 0x03000000
+import six
 
 DEFAULT_BASE_URL = "https://api.github.com"
 DEFAULT_STATUS_URL = "https://status.github.com"
@@ -108,14 +104,14 @@ class Github(object):
         :param retry: int or urllib3.util.retry.Retry object
         """
 
-        assert login_or_token is None or isinstance(login_or_token, str), login_or_token
-        assert password is None or isinstance(password, str), password
-        assert jwt is None or isinstance(jwt, str), jwt
-        assert isinstance(base_url, str), base_url
-        assert isinstance(timeout, int), timeout
-        assert client_id is None or isinstance(client_id, str), client_id
-        assert client_secret is None or isinstance(client_secret, str), client_secret
-        assert user_agent is None or isinstance(user_agent, str), user_agent
+        assert login_or_token is None or isinstance(login_or_token, (str, six.text_type)), login_or_token
+        assert password is None or isinstance(password, (str, six.text_type)), password
+        assert jwt is None or isinstance(jwt, (str, six.text_type)), jwt
+        assert isinstance(base_url, (str, six.text_type)), base_url
+        assert isinstance(timeout, six.integer_types), timeout
+        assert client_id is None or isinstance(client_id, (str, six.text_type)), client_id
+        assert client_secret is None or isinstance(client_secret, (str, six.text_type)), client_secret
+        assert user_agent is None or isinstance(user_agent, (str, six.text_type)), user_agent
         assert isinstance(api_preview, (bool))
         assert retry is None or isinstance(retry, (int)) or isinstance(retry, (urllib3.util.Retry))
         self.__requester = Requester(login_or_token, password, jwt, base_url, timeout, client_id, client_secret, user_agent, per_page, api_preview, verify, retry)
@@ -196,7 +192,7 @@ class Github(object):
         :rtype: :class:`github.License.License`
         """
 
-        assert isinstance(key, str), key
+        assert isinstance(key, (str, six.text_type)), key
         headers, data = self.__requester.requestJsonAndCheck(
             "GET",
             "/licenses/" + key
@@ -224,7 +220,7 @@ class Github(object):
         :param login: string
         :rtype: :class:`github.NamedUser.NamedUser`
         """
-        assert login is github.GithubObject.NotSet or isinstance(login, str), login
+        assert login is github.GithubObject.NotSet or isinstance(login, (str, six.text_type)), login
         if login is github.GithubObject.NotSet:
             return AuthenticatedUser.AuthenticatedUser(self.__requester, {}, {"url": "/user"}, completed=False)
         else:
@@ -240,7 +236,7 @@ class Github(object):
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, int), since
+        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
@@ -257,7 +253,7 @@ class Github(object):
         :param login: string
         :rtype: :class:`github.Organization.Organization`
         """
-        assert isinstance(login, str), login
+        assert isinstance(login, (str, six.text_type)), login
         headers, data = self.__requester.requestJsonAndCheck(
             "GET",
             "/orgs/" + login
@@ -270,12 +266,12 @@ class Github(object):
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Organization.Organization`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, int), since
+        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
         return github.PaginatedList.PaginatedList(
-            github.NamedUser.NamedUser,
+            github.Organization.Organization,
             self.__requester,
             "/organizations",
             url_parameters
@@ -286,8 +282,8 @@ class Github(object):
         :calls: `GET /repos/:owner/:repo <http://developer.github.com/v3/repos>`_ or `GET /repositories/:id <http://developer.github.com/v3/repos>`_
         :rtype: :class:`github.Repository.Repository`
         """
-        assert isinstance(full_name_or_id, (str, int)), full_name_or_id
-        url_base = "/repositories/" if isinstance(full_name_or_id, int) or isinstance(full_name_or_id, int) else "/repos/"
+        assert isinstance(full_name_or_id, (str, six.text_type, int)), full_name_or_id
+        url_base = "/repositories/" if isinstance(full_name_or_id, int) else "/repos/"
         url = "%s%s" % (url_base, full_name_or_id)
         if lazy:
             return Repository.Repository(self.__requester, {}, {"url": url}, completed=False)
@@ -297,16 +293,20 @@ class Github(object):
         )
         return Repository.Repository(self.__requester, headers, data, completed=True)
 
-    def get_repos(self, since=github.GithubObject.NotSet):
+    def get_repos(self, since=github.GithubObject.NotSet, visibility=github.GithubObject.NotSet):
         """
         :calls: `GET /repositories <http://developer.github.com/v3/repos/#list-all-public-repositories>`_
         :param since: integer
+        :param visibility: string ('all','public')
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, int), since
+        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
+        if visibility is not github.GithubObject.NotSet:
+            assert visibility in ('public', 'all'), visibility
+            url_parameters["visibility"] = visibility
         return github.PaginatedList.PaginatedList(
             github.Repository.Repository,
             self.__requester,
@@ -333,7 +333,7 @@ class Github(object):
         :param id: string
         :rtype: :class:`github.Gist.Gist`
         """
-        assert isinstance(id, str), id
+        assert isinstance(id, (str, six.text_type)), id
         headers, data = self.__requester.requestJsonAndCheck(
             "GET",
             "/gists/" + id
@@ -366,7 +366,7 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert sort in ('stars', 'forks', 'updated'), sort
@@ -379,7 +379,7 @@ class Github(object):
         if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -401,7 +401,7 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:
             assert sort in ('followers', 'repositories', 'joined'), sort
@@ -414,7 +414,7 @@ class Github(object):
         if query:
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -436,7 +436,7 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Issue.Issue`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:
             assert sort in ('comments', 'created', 'updated'), sort
@@ -449,7 +449,7 @@ class Github(object):
         if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -472,7 +472,7 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.ContentFile.ContentFile`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert sort in ('indexed',), sort
@@ -485,7 +485,7 @@ class Github(object):
         if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -510,7 +510,7 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Commit.Commit`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert sort in ('author-date', 'committer-date'), sort
@@ -523,7 +523,7 @@ class Github(object):
         if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -546,14 +546,14 @@ class Github(object):
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Topic.Topic`
         """
-        assert isinstance(query, str), query
+        assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
 
         query_chunks = []
         if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
-        for qualifier, value in list(qualifiers.items()):
+        for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
         url_parameters["q"] = ' '.join(query_chunks)
@@ -576,7 +576,7 @@ class Github(object):
         :param context: :class:`github.Repository.Repository`
         :rtype: string
         """
-        assert isinstance(text, str), text
+        assert isinstance(text, (str, six.text_type)), text
         assert context is github.GithubObject.NotSet or isinstance(context, github.Repository.Repository), context
         post_parameters = {
             "text": text
@@ -597,7 +597,7 @@ class Github(object):
         :param name: string
         :rtype: :class:`github.HookDescription.HookDescription`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         headers, attributes = self.__requester.requestJsonAndCheck(
             "GET",
             "/hooks/" + name
@@ -631,7 +631,7 @@ class Github(object):
         :calls: `GET /gitignore/templates/:name <http://developer.github.com/v3/gitignore>`_
         :rtype: :class:`github.GitignoreTemplate.GitignoreTemplate`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         headers, attributes = self.__requester.requestJsonAndCheck(
             "GET",
             "/gitignore/templates/" + name
@@ -696,13 +696,16 @@ class GithubIntegration(object):
     Main class to obtain tokens for a GitHub integration.
     """
 
-    def __init__(self, integration_id, private_key):
+    def __init__(self, integration_id, private_key, base_url=DEFAULT_BASE_URL):
         """
+        :param base_url: string
         :param integration_id: int
         :param private_key: string
         """
+        self.base_url = base_url
         self.integration_id = integration_id
         self.private_key = private_key
+        assert isinstance(base_url, (str, six.text_type)), base_url
 
     def create_jwt(self, expiration=60):
         """
@@ -724,7 +727,7 @@ class GithubIntegration(object):
             algorithm="RS256"
         )
 
-        if atLeastPython3:
+        if isinstance(encrypted, bytes):
             encrypted = encrypted.decode('utf-8')
 
         return encrypted
@@ -741,7 +744,7 @@ class GithubIntegration(object):
         if user_id:
             body = {"user_id": user_id}
         response = requests.post(
-            "https://api.github.com/app/installations/{}/access_tokens".format(installation_id),
+            "{}/app/installations/{}/access_tokens".format(self.base_url, installation_id),
             headers={
                 "Authorization": "Bearer {}".format(self.create_jwt()),
                 "Accept": Consts.mediaTypeIntegrationPreview,
@@ -771,3 +774,23 @@ class GithubIntegration(object):
             status=response.status_code,
             data=response.text
         )
+
+    def get_installation(self, owner, repo):
+        """
+        :calls: `GET /repos/:owner/:repo/installation <https://developer.github.com/v3/apps/#get-a-repository-installation>`_
+        :param owner: str
+        :param repo: str
+        :rtype: :class:`github.Installation.Installation`
+        """
+        headers = {
+            "Authorization": "Bearer {}".format(self.create_jwt()),
+            "Accept": Consts.mediaTypeIntegrationPreview,
+            "User-Agent": "PyGithub/Python",
+        }
+
+        response = requests.get(
+            "{}/repos/{}/{}/installation".format(self.base_url, owner, repo),
+            headers=headers
+        )
+        response_dict = response.json()
+        return Installation.Installation(None, headers, response_dict, True)
