@@ -41,8 +41,8 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import datetime
-import json
 
 import github.GithubObject
 import github.PaginatedList
@@ -55,6 +55,8 @@ import github.Project
 import github.NamedUser
 
 from . import Consts
+import six
+
 
 class Organization(github.GithubObject.CompletableGithubObject):
     """
@@ -280,6 +282,14 @@ class Organization(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._total_private_repos)
         return self._total_private_repos.value
 
+    @property
+    def two_factor_requirement_enabled(self):
+        """
+        :type: bool
+        """
+        self._completeIfNotSet(self._two_factor_requirement_enabled)
+        return self._two_factor_requirement_enabled.value
+
     @property
     def type(self):
         """
@@ -311,7 +321,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param role: string
         :rtype: None
         """
-        assert isinstance(role, str), role
+        assert role is github.GithubObject.NotSet or isinstance(role, (str, six.text_type)), role
         assert isinstance(member, github.NamedUser.NamedUser), member
         put_parameters = {}
         if role is not github.GithubObject.NotSet:
@@ -359,9 +369,9 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param active: bool
         :rtype: :class:`github.Hook.Hook`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         assert isinstance(config, dict), config
-        assert events is github.GithubObject.NotSet or all(isinstance(element, str) for element in events), events
+        assert events is github.GithubObject.NotSet or all(isinstance(element, (str, six.text_type)) for element in events), events
         assert active is github.GithubObject.NotSet or isinstance(active, bool), active
         post_parameters = {
             "name": name,
@@ -404,18 +414,18 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param allow_rebase_merge: bool
         :rtype: :class:`github.Repository.Repository`
         """
-        assert isinstance(name, str), name
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
-        assert homepage is github.GithubObject.NotSet or isinstance(homepage, str), homepage
+        assert isinstance(name, (str, six.text_type)), name
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
+        assert homepage is github.GithubObject.NotSet or isinstance(homepage, (str, six.text_type)), homepage
         assert private is github.GithubObject.NotSet or isinstance(private, bool), private
         assert has_issues is github.GithubObject.NotSet or isinstance(has_issues, bool), has_issues
         assert has_wiki is github.GithubObject.NotSet or isinstance(has_wiki, bool), has_wiki
         assert has_downloads is github.GithubObject.NotSet or isinstance(has_downloads, bool), has_downloads
         assert has_projects is github.GithubObject.NotSet or isinstance(has_projects, bool), has_projects
-        assert team_id is github.GithubObject.NotSet or isinstance(team_id, int), team_id
+        assert team_id is github.GithubObject.NotSet or isinstance(team_id, six.integer_types), team_id
         assert auto_init is github.GithubObject.NotSet or isinstance(auto_init, bool), auto_init
-        assert license_template is github.GithubObject.NotSet or isinstance(license_template, str), license_template
-        assert gitignore_template is github.GithubObject.NotSet or isinstance(gitignore_template, str), gitignore_template
+        assert license_template is github.GithubObject.NotSet or isinstance(license_template, (str, six.text_type)), license_template
+        assert gitignore_template is github.GithubObject.NotSet or isinstance(gitignore_template, (str, six.text_type)), gitignore_template
         assert allow_squash_merge is github.GithubObject.NotSet or isinstance(allow_squash_merge, bool), allow_squash_merge
         assert allow_merge_commit is github.GithubObject.NotSet or isinstance(allow_merge_commit, bool), allow_merge_commit
         assert allow_rebase_merge is github.GithubObject.NotSet or isinstance(allow_rebase_merge, bool), allow_rebase_merge
@@ -457,19 +467,21 @@ class Organization(github.GithubObject.CompletableGithubObject):
         )
         return github.Repository.Repository(self._requester, headers, data, completed=True)
 
-    def create_team(self, name, repo_names=github.GithubObject.NotSet, permission=github.GithubObject.NotSet, privacy=github.GithubObject.NotSet):
+    def create_team(self, name, repo_names=github.GithubObject.NotSet, permission=github.GithubObject.NotSet, privacy=github.GithubObject.NotSet, description=github.GithubObject.NotSet):
         """
         :calls: `POST /orgs/:org/teams <http://developer.github.com/v3/orgs/teams>`_
         :param name: string
         :param repo_names: list of :class:`github.Repository.Repository`
         :param permission: string
         :param privacy: string
+        :param description: string
         :rtype: :class:`github.Team.Team`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         assert repo_names is github.GithubObject.NotSet or all(isinstance(element, github.Repository.Repository) for element in repo_names), repo_names
-        assert permission is github.GithubObject.NotSet or isinstance(permission, str), permission
-        assert privacy is github.GithubObject.NotSet or isinstance(privacy, str), privacy
+        assert permission is github.GithubObject.NotSet or isinstance(permission, (str, six.text_type)), permission
+        assert privacy is github.GithubObject.NotSet or isinstance(privacy, (str, six.text_type)), privacy
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
         post_parameters = {
             "name": name,
         }
@@ -479,6 +491,8 @@ class Organization(github.GithubObject.CompletableGithubObject):
             post_parameters["permission"] = permission
         if privacy is not github.GithubObject.NotSet:
             post_parameters['privacy'] = privacy
+        if description is not github.GithubObject.NotSet:
+            post_parameters["description"] = description
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self.url + "/teams",
@@ -492,7 +506,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: None`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url + "/hooks/" + str(id)
@@ -510,13 +524,13 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param name: string
         :rtype: None
         """
-        assert billing_email is github.GithubObject.NotSet or isinstance(billing_email, str), billing_email
-        assert blog is github.GithubObject.NotSet or isinstance(blog, str), blog
-        assert company is github.GithubObject.NotSet or isinstance(company, str), company
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
-        assert email is github.GithubObject.NotSet or isinstance(email, str), email
-        assert location is github.GithubObject.NotSet or isinstance(location, str), location
-        assert name is github.GithubObject.NotSet or isinstance(name, str), name
+        assert billing_email is github.GithubObject.NotSet or isinstance(billing_email, (str, six.text_type)), billing_email
+        assert blog is github.GithubObject.NotSet or isinstance(blog, (str, six.text_type)), blog
+        assert company is github.GithubObject.NotSet or isinstance(company, (str, six.text_type)), company
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
+        assert email is github.GithubObject.NotSet or isinstance(email, (str, six.text_type)), email
+        assert location is github.GithubObject.NotSet or isinstance(location, (str, six.text_type)), location
+        assert name is github.GithubObject.NotSet or isinstance(name, (str, six.text_type)), name
         post_parameters = dict()
         if billing_email is not github.GithubObject.NotSet:
             post_parameters["billing_email"] = billing_email
@@ -549,10 +563,10 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param active: bool
         :rtype: :class:`github.Hook.Hook`
         """
-        assert isinstance(id, int), id
-        assert isinstance(name, str), name
+        assert isinstance(id, six.integer_types), id
+        assert isinstance(name, (str, six.text_type)), name
         assert isinstance(config, dict), config
-        assert events is github.GithubObject.NotSet or all(isinstance(element, str) for element in events), events
+        assert events is github.GithubObject.NotSet or all(isinstance(element, (str, six.text_type)) for element in events), events
         assert active is github.GithubObject.NotSet or isinstance(active, bool), active
         post_parameters = {
             "name": name,
@@ -587,7 +601,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.Hook.Hook`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self.url + "/hooks/" + str(id)
@@ -618,11 +632,11 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param since: datetime.datetime
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Issue.Issue`
         """
-        assert filter is github.GithubObject.NotSet or isinstance(filter, str), filter
-        assert state is github.GithubObject.NotSet or isinstance(state, str), state
+        assert filter is github.GithubObject.NotSet or isinstance(filter, (str, six.text_type)), filter
+        assert state is github.GithubObject.NotSet or isinstance(state, (str, six.text_type)), state
         assert labels is github.GithubObject.NotSet or all(isinstance(element, github.Label.Label) for element in labels), labels
-        assert sort is github.GithubObject.NotSet or isinstance(sort, str), sort
-        assert direction is github.GithubObject.NotSet or isinstance(direction, str), direction
+        assert sort is github.GithubObject.NotSet or isinstance(sort, (str, six.text_type)), sort
+        assert direction is github.GithubObject.NotSet or isinstance(direction, (str, six.text_type)), direction
         assert since is github.GithubObject.NotSet or isinstance(since, datetime.datetime), since
         url_parameters = dict()
         if filter is not github.GithubObject.NotSet:
@@ -652,10 +666,10 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param role: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert (filter_ is github.GithubObject.NotSet or
-                isinstance(filter_, str)), filter_
-        assert (role is github.GithubObject.NotSet or
-                isinstance(role, str)), role
+        assert (filter_ is github.GithubObject.NotSet
+                or isinstance(filter_, (str, six.text_type))), filter_
+        assert (role is github.GithubObject.NotSet
+                or isinstance(role, (str, six.text_type))), role
 
         url_parameters = {}
         if filter_ is not github.GithubObject.NotSet:
@@ -675,11 +689,11 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Project.Project`
         :param state: string
         """
-        
+
         url_parameters = dict()
         if state is not github.GithubObject.NotSet:
             url_parameters["state"] = state
-            
+
         return github.PaginatedList.PaginatedList(
             github.Project.Project,
             self._requester,
@@ -687,7 +701,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
             url_parameters,
             {"Accept": Consts.mediaTypeProjectsPreview}
         )
-        
+
     def get_public_members(self):
         """
         :calls: `GET /orgs/:org/public_members <http://developer.github.com/v3/orgs/members>`_
@@ -706,8 +720,8 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param filter_: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert (filter_ is github.GithubObject.NotSet or
-                isinstance(filter_, str)), filter_
+        assert (filter_ is github.GithubObject.NotSet
+                or isinstance(filter_, (str, six.text_type))), filter_
 
         url_parameters = {}
         if filter_ is not github.GithubObject.NotSet:
@@ -749,23 +763,32 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param name: string
         :rtype: :class:`github.Repository.Repository`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             "/repos/" + self.login + "/" + name
         )
         return github.Repository.Repository(self._requester, headers, data, completed=True)
 
-    def get_repos(self, type=github.GithubObject.NotSet):
+    def get_repos(self, type=github.GithubObject.NotSet, sort=github.GithubObject.NotSet, direction=github.GithubObject.NotSet):
         """
         :calls: `GET /orgs/:org/repos <http://developer.github.com/v3/repos>`_
         :param type: string ('all', 'public', 'private', 'forks', 'sources', 'member')
+        :param sort: string ('created', 'updated', 'pushed', 'full_name')
+        :param direction: string ('asc', desc')
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert type is github.GithubObject.NotSet or isinstance(type, str), type
+        assert type is github.GithubObject.NotSet or isinstance(type, (str, six.text_type)), type
+        assert sort is github.GithubObject.NotSet or isinstance(sort, (str, six.text_type)), sort
+        assert direction is github.GithubObject.NotSet or isinstance(direction, (str, six.text_type)), direction
+
         url_parameters = dict()
         if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
+        if sort is not github.GithubObject.NotSet:
+            url_parameters["sort"] = sort
+        if direction is not github.GithubObject.NotSet:
+            url_parameters["direction"] = direction
         return github.PaginatedList.PaginatedList(
             github.Repository.Repository,
             self._requester,
@@ -779,13 +802,26 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.Team.Team`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             "/teams/" + str(id)
         )
         return github.Team.Team(self._requester, headers, data, completed=True)
 
+    def get_team_by_slug(self, slug):
+        """
+        :calls: `GET /orgs/:org/teams/:team_slug <https://developer.github.com/v3/teams>`_
+        :param slug: string
+        :rtype: :class:`github.Team.Team`
+        """
+        assert isinstance(slug, (str, six.text_type)), slug
+        headers, data = self._requester.requestJsonAndCheck(
+            "GET",
+            self.url + "/teams/" + slug
+        )
+        return github.Team.Team(self._requester, headers, data, completed=True)
+
     def get_teams(self):
         """
         :calls: `GET /orgs/:org/teams <http://developer.github.com/v3/orgs/teams>`_
@@ -798,6 +834,21 @@ class Organization(github.GithubObject.CompletableGithubObject):
             None
         )
 
+    def invitations(self):
+        """
+        :calls: `GET /orgs/:org/invitations <https://developer.github.com/v3/orgs/members>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
+            self._requester,
+            self.url + "/invitations",
+            None,
+            headers={
+                "Accept": Consts.mediaTypeOrganizationInvitationPreview
+            }
+        )
+
     def invite_user(self, user=github.GithubObject.NotSet, email=github.GithubObject.NotSet, role=github.GithubObject.NotSet, teams=github.GithubObject.NotSet):
         """
         :calls: `POST /orgs/:org/invitations <http://developer.github.com/v3/orgs/members>`_
@@ -808,7 +859,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :rtype: None
         """
         assert user is github.GithubObject.NotSet or isinstance(user, github.NamedUser.NamedUser), user
-        assert email is github.GithubObject.NotSet or isinstance(email, str), email
+        assert email is github.GithubObject.NotSet or isinstance(email, (str, six.text_type)), email
         assert (email is github.GithubObject.NotSet) ^ (user is github.GithubObject.NotSet), "specify only one of email or user"
         parameters = {}
         if user is not github.GithubObject.NotSet:
@@ -816,7 +867,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         elif email is not github.GithubObject.NotSet:
             parameters["email"] = email
         if role is not github.GithubObject.NotSet:
-            assert isinstance(role, str), role
+            assert isinstance(role, (str, six.text_type)), role
             assert role in ['admin', 'direct_member', 'billing_manager']
             parameters["role"] = role
         if teams is not github.GithubObject.NotSet:
@@ -905,7 +956,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.Migration.Migration`
         """
         assert isinstance(repos, (list, tuple)), repos
-        assert all(isinstance(repo, str) for repo in repos), repos
+        assert all(isinstance(repo, (str, six.text_type)) for repo in repos), repos
         assert lock_repositories is github.GithubObject.NotSet or isinstance(lock_repositories, bool), lock_repositories
         assert exclude_attachments is github.GithubObject.NotSet or isinstance(exclude_attachments, bool), exclude_attachments
         post_parameters = {
@@ -941,6 +992,7 @@ class Organization(github.GithubObject.CompletableGithubObject):
         )
 
     def _initAttributes(self):
+        self._two_factor_requirement_enabled = github.GithubObject.NotSet
         self._avatar_url = github.GithubObject.NotSet
         self._billing_email = github.GithubObject.NotSet
         self._blog = github.GithubObject.NotSet
@@ -1027,6 +1079,8 @@ class Organization(github.GithubObject.CompletableGithubObject):
             self._repos_url = self._makeStringAttribute(attributes["repos_url"])
         if "total_private_repos" in attributes:  # pragma no branch
             self._total_private_repos = self._makeIntAttribute(attributes["total_private_repos"])
+        if "two_factor_requirement_enabled" in attributes:  # pragma no branch
+            self._two_factor_requirement_enabled = self._makeBoolAttribute(attributes["two_factor_requirement_enabled"])
         if "type" in attributes:  # pragma no branch
             self._type = self._makeStringAttribute(attributes["type"])
         if "updated_at" in attributes:  # pragma no branch
