@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+import six
 # -*- coding: utf-8 -*-
 
 ############################ Copyrights and license ############################
@@ -37,10 +39,7 @@
 #                                                                              #
 ################################################################################
 
-try:
-    from urllib.parse import parse_qs
-except ImportError:
-    from urllib.parse import parse_qs
+from six.moves.urllib.parse import parse_qs
 
 
 class PaginatedListBase:
@@ -49,7 +48,7 @@ class PaginatedListBase:
 
     def __getitem__(self, index):
         assert isinstance(index, (int, slice))
-        if isinstance(index, int):
+        if isinstance(index, six.integer_types):
             self.__fetchToIndex(index)
             return self.__elements[index]
         else:
