@@ -42,8 +42,9 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import datetime
-import urllib.request, urllib.parse, urllib.error
+import six.moves.urllib.parse
 import github.GithubObject
 import github.PaginatedList
 
@@ -57,6 +58,7 @@ import github.Commit
 import github.PullRequestReview
 
 from . import Consts
+import six
 
 
 class PullRequest(github.GithubObject.CompletableGithubObject):
@@ -386,10 +388,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param position: integer
         :rtype: :class:`github.PullRequestComment.PullRequestComment`
         """
-        assert isinstance(body, str), body
+        assert isinstance(body, (str, six.text_type)), body
         assert isinstance(commit_id, github.Commit.Commit), commit_id
-        assert isinstance(path, str), path
-        assert isinstance(position, int), position
+        assert isinstance(path, (str, six.text_type)), path
+        assert isinstance(position, six.integer_types), position
         post_parameters = {
             "body": body,
             "commit_id": commit_id._identity,
@@ -409,7 +411,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param body: string
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(body, str), body
+        assert isinstance(body, (str, six.text_type)), body
         post_parameters = {
             "body": body,
         }
@@ -420,7 +422,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         )
         return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
-    def create_review(self, commit=github.GithubObject.NotSet, body=None, event=github.GithubObject.NotSet, comments=github.GithubObject.NotSet):
+    def create_review(self, commit=github.GithubObject.NotSet, body=github.GithubObject.NotSet, event=github.GithubObject.NotSet, comments=github.GithubObject.NotSet):
         """
         :calls: `POST /repos/:owner/:repo/pulls/:number/reviews <https://developer.github.com/v3/pulls/reviews/>`_
         :param commit: github.Commit.Commit
@@ -430,13 +432,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PullRequestReview.PullRequestReview`
         """
         assert commit is github.GithubObject.NotSet or isinstance(commit, github.Commit.Commit), commit
-        assert isinstance(body, str), body
+        assert body is github.GithubObject.NotSet or isinstance(body, str), body
         assert event is github.GithubObject.NotSet or isinstance(event, str), event
         assert comments is github.GithubObject.NotSet or isinstance(comments, list), comments
         post_parameters = dict()
         if commit is not github.GithubObject.NotSet:
             post_parameters['commit_id'] = commit.sha
-        post_parameters['body'] = body
+        if body is not github.GithubObject.NotSet:
+            post_parameters['body'] = body
         post_parameters['event'] = 'COMMENT' if event == github.GithubObject.NotSet else event
         if comments is github.GithubObject.NotSet:
             post_parameters['comments'] = []
@@ -447,7 +450,6 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             self.url + "/reviews",
             input=post_parameters
         )
-        self._useAttributes(data)
         return github.PullRequestReview.PullRequestReview(self._requester, headers, data, completed=True)
 
     def create_review_request(self, reviewers=github.GithubObject.NotSet, team_reviewers=github.GithubObject.NotSet):
@@ -459,10 +461,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         """
         post_parameters = dict()
         if reviewers is not github.GithubObject.NotSet:
-            assert all(isinstance(element, str) for element in reviewers), reviewers
+            assert all(isinstance(element, (str, six.text_type)) for element in reviewers), reviewers
             post_parameters["reviewers"] = reviewers
         if team_reviewers is not github.GithubObject.NotSet:
-            assert all(isinstance(element, str) for element in team_reviewers), team_reviewers
+            assert all(isinstance(element, (str, six.text_type)) for element in team_reviewers), team_reviewers
             post_parameters["team_reviewers"] = team_reviewers
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
@@ -479,10 +481,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         """
         post_parameters = dict()
         if reviewers is not github.GithubObject.NotSet:
-            assert all(isinstance(element, str) for element in reviewers), reviewers
+            assert all(isinstance(element, (str, six.text_type)) for element in reviewers), reviewers
             post_parameters["reviewers"] = reviewers
         if team_reviewers is not github.GithubObject.NotSet:
-            assert all(isinstance(element, str) for element in team_reviewers), team_reviewers
+            assert all(isinstance(element, (str, six.text_type)) for element in team_reviewers), team_reviewers
             post_parameters["team_reviewers"] = team_reviewers
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
@@ -499,10 +501,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param base: string
         :rtype: None
         """
-        assert title is github.GithubObject.NotSet or isinstance(title, str), title
-        assert body is github.GithubObject.NotSet or isinstance(body, str), body
-        assert state is github.GithubObject.NotSet or isinstance(state, str), state
-        assert base is github.GithubObject.NotSet or isinstance(base, str), base
+        assert title is github.GithubObject.NotSet or isinstance(title, (str, six.text_type)), title
+        assert body is github.GithubObject.NotSet or isinstance(body, (str, six.text_type)), body
+        assert state is github.GithubObject.NotSet or isinstance(state, (str, six.text_type)), state
+        assert base is github.GithubObject.NotSet or isinstance(base, (str, six.text_type)), base
         post_parameters = dict()
         if title is not github.GithubObject.NotSet:
             post_parameters["title"] = title
@@ -533,7 +535,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.PullRequestComment.PullRequestComment`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self._parentUrl(self.url) + "/comments/" + str(id)
@@ -572,7 +574,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestComment.PullRequestComment`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         return github.PaginatedList.PaginatedList(
             github.PullRequestComment.PullRequestComment,
             self._requester,
@@ -610,7 +612,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self._parentUrl(self.issue_url) + "/comments/" + str(id)
@@ -648,7 +650,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param id: integer
         :rtype: :class:`github.PullRequestReview.PullRequestReview`
         """
-        assert isinstance(id, int), id
+        assert isinstance(id, six.integer_types), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             self.url + "/reviews/" + str(id),
@@ -707,7 +709,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str)) for element in labels), labels
+        assert all(isinstance(element, (github.Label.Label, str, six.text_type)) for element in labels), labels
         post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
@@ -731,11 +733,11 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert isinstance(label, (github.Label.Label, str)), label
+        assert isinstance(label, (github.Label.Label, str, six.text_type)), label
         if isinstance(label, github.Label.Label):
             label = label._identity
         else:
-            label = urllib.parse.quote(label)
+            label = six.moves.urllib.parse.quote(label)
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.issue_url + "/labels/" + label
@@ -747,7 +749,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param labels: list of :class:`github.Label.Label` or strings
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str)) for element in labels), labels
+        assert all(isinstance(element, (github.Label.Label, str, six.text_type)) for element in labels), labels
         post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
@@ -772,10 +774,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         :param commit_message: string
         :rtype: :class:`github.PullRequestMergeStatus.PullRequestMergeStatus`
         """
-        assert commit_message is github.GithubObject.NotSet or isinstance(commit_message, str), commit_message
-        assert commit_title is github.GithubObject.NotSet or isinstance(commit_title, str), commit_title
-        assert merge_method is github.GithubObject.NotSet or isinstance(merge_method, str), merge_method
-        assert sha is github.GithubObject.NotSet or isinstance(sha, str), sha
+        assert commit_message is github.GithubObject.NotSet or isinstance(commit_message, (str, six.text_type)), commit_message
+        assert commit_title is github.GithubObject.NotSet or isinstance(commit_title, (str, six.text_type)), commit_title
+        assert merge_method is github.GithubObject.NotSet or isinstance(merge_method, (str, six.text_type)), merge_method
+        assert sha is github.GithubObject.NotSet or isinstance(sha, (str, six.text_type)), sha
         post_parameters = dict()
         if commit_message is not github.GithubObject.NotSet:
             post_parameters["commit_message"] = commit_message
@@ -792,6 +794,36 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         )
         return github.PullRequestMergeStatus.PullRequestMergeStatus(self._requester, headers, data, completed=True)
 
+    def add_to_assignees(self, *assignees):
+        """
+        :calls: `POST /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :param assignees: list of :class:`github.NamedUser.NamedUser` or string
+        :rtype: None
+        """
+        assert all(isinstance(element, (github.NamedUser.NamedUser, str)) for element in assignees), assignees
+        post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
+        headers, data = self._requester.requestJsonAndCheck(
+            "POST",
+            self.url + "/assignees",
+            input=post_parameters
+        )
+        self._useAttributes(data)
+
+    def remove_from_assignees(self, *assignees):
+        """
+        :calls: `DELETE /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :param assignees: list of :class:`github.NamedUser.NamedUser` or string
+        :rtype: None
+        """
+        assert all(isinstance(element, (github.NamedUser.NamedUser, str)) for element in assignees), assignees
+        post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
+        headers, data = self._requester.requestJsonAndCheck(
+            "DELETE",
+            self.url + "/assignees",
+            input=post_parameters
+        )
+        self._useAttributes(data)
+
     def _initAttributes(self):
         self._additions = github.GithubObject.NotSet
         self._assignee = github.GithubObject.NotSet
