@@ -34,10 +34,12 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
 import github.NamedUser
 
 from . import Consts
+import six
 
 
 class PullRequestComment(github.GithubObject.CompletableGithubObject):
@@ -184,7 +186,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :param body: string
         :rtype: None
         """
-        assert isinstance(body, str), body
+        assert isinstance(body, (str, six.text_type)), body
         post_parameters = {
             "body": body,
         }
@@ -216,7 +218,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :param reaction_type: string
         :rtype: :class:`github.Reaction.Reaction`
         """
-        assert isinstance(reaction_type, str), "reaction type should be a string"
+        assert isinstance(reaction_type, (str, six.text_type)), "reaction type should be a string"
         assert reaction_type in ["+1", "-1", "laugh", "confused", "heart", "hooray"], \
             "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
 
