@@ -26,9 +26,11 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
 
 import github.NamedUser
+import six
 
 
 class PullRequestReview(github.GithubObject.CompletableGithubObject):
@@ -116,7 +118,7 @@ class PullRequestReview(github.GithubObject.CompletableGithubObject):
         :calls: `PUT /repos/:owner/:repo/pulls/:number/reviews/:review_id/dismissals <https://developer.github.com/v3/pulls/reviews/>`_
         :rtype: None
         """
-        assert isinstance(message, str), message
+        assert isinstance(message, (str, six.text_type)), message
         post_parameters = {'message': message}
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
