@@ -41,14 +41,17 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 import github.GithubObject
 import github.PaginatedList
 
 import github.Repository
 import github.NamedUser
 import github.Organization
+import github.TeamDiscussion
 
 from . import Consts
+import six
 
 
 class Team(github.GithubObject.CompletableGithubObject):
@@ -179,7 +182,7 @@ class Team(github.GithubObject.CompletableGithubObject):
         """
         assert isinstance(member, github.NamedUser.NamedUser), member
         assert role is github.GithubObject.NotSet or isinstance(
-            role, str), role
+            role, (str, six.text_type)), role
         if role is not github.GithubObject.NotSet:
             assert role in ['member', 'maintainer']
             put_parameters = {
@@ -243,10 +246,10 @@ class Team(github.GithubObject.CompletableGithubObject):
         :param privacy: string
         :rtype: None
         """
-        assert isinstance(name, str), name
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
-        assert permission is github.GithubObject.NotSet or isinstance(permission, str), permission
-        assert privacy is github.GithubObject.NotSet or isinstance(privacy, str), privacy
+        assert isinstance(name, (str, six.text_type)), name
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
+        assert permission is github.GithubObject.NotSet or isinstance(permission, (str, six.text_type)), permission
+        assert privacy is github.GithubObject.NotSet or isinstance(privacy, (str, six.text_type)), privacy
         post_parameters = {
             "name": name,
         }
@@ -263,13 +266,28 @@ class Team(github.GithubObject.CompletableGithubObject):
         )
         self._useAttributes(data)
 
+    def get_discussions(self):
+        """
+        :calls: `GET /teams/:id/discussions <https://developer.github.com/v3/teams/discussions/#list-discussions>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.TeamDiscussion.TeamDiscussion`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.TeamDiscussion.TeamDiscussion,
+            self._requester,
+            self.url + "/discussions",
+            None,
+            headers={
+                "Accept": Consts.mediaTypeTeamDiscussionsPreview
+            }
+        )
+
     def get_members(self, role=github.GithubObject.NotSet):
         """
         :calls: `GET /teams/:id/members <https://developer.github.com/v3/teams/members/#list-team-members>`_
         :param role: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert role is github.GithubObject.NotSet or isinstance(role, str), role
+        assert role is github.GithubObject.NotSet or isinstance(role, (str, six.text_type)), role
         url_parameters = dict()
         if role is not github.GithubObject.NotSet:
             assert role in ['member', 'maintainer', 'all']
